==> open-cluster-management-cluster-model-6.1.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/PlacementListFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PlacementListFluent<A extends PlacementListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Placement item);
  public A setToItems(Integer index,Placement item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.Placement... items);
  public A addAllToItems(Collection<Placement> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.Placement... items);
  public A removeAllFromItems(Collection<Placement> items);
  public A removeMatchingFromItems(Predicate<PlacementBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Placement> getItems();
  public List<Placement> buildItems();
  public Placement buildItem(Integer index);
  public Placement buildFirstItem();
  public Placement buildLastItem();
  public Placement buildMatchingItem(Predicate<PlacementBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PlacementBuilder> predicate);
  public A withItems(List<Placement> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.Placement... items);
  public Boolean hasItems();
  public PlacementListFluent.ItemsNested<A> addNewItem();
  public PlacementListFluent.ItemsNested<A> addNewItemLike(Placement item);
  public PlacementListFluent.ItemsNested<A> setNewItemLike(Integer index,Placement item);
  public PlacementListFluent.ItemsNested<A> editItem(Integer index);
  public PlacementListFluent.ItemsNested<A> editFirstItem();
  public PlacementListFluent.ItemsNested<A> editLastItem();
  public PlacementListFluent.ItemsNested<A> editMatchingItem(Predicate<PlacementBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,PlacementFluent<PlacementListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-cluster-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/PlacementListFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PlacementListFluent<A extends PlacementListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Placement item);
  public A setToItems(int index,Placement item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.Placement... items);
  public A addAllToItems(Collection<Placement> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.Placement... items);
  public A removeAllFromItems(Collection<Placement> items);
  public A removeMatchingFromItems(Predicate<PlacementBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Placement> getItems();
  public List<Placement> buildItems();
  public Placement buildItem(int index);
  public Placement buildFirstItem();
  public Placement buildLastItem();
  public Placement buildMatchingItem(Predicate<PlacementBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PlacementBuilder> predicate);
  public A withItems(List<Placement> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.Placement... items);
  public Boolean hasItems();
  public PlacementListFluent.ItemsNested<A> addNewItem();
  public PlacementListFluent.ItemsNested<A> addNewItemLike(Placement item);
  public PlacementListFluent.ItemsNested<A> setNewItemLike(int index,Placement item);
  public PlacementListFluent.ItemsNested<A> editItem(int index);
  public PlacementListFluent.ItemsNested<A> editFirstItem();
  public PlacementListFluent.ItemsNested<A> editLastItem();
  public PlacementListFluent.ItemsNested<A> editMatchingItem(Predicate<PlacementBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,PlacementFluent<PlacementListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
